# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.1] - 2025-12-02

### Added
- Initial release
- Nova API model provider for Strands Agents SDK
- Full streaming support with SSE
- Comprehensive unit tests
- GitHub Actions CI/CD pipeline
- PyPI package publication